import {trierCandidats} from "../utils"
import TableContainer from "@mui/material/TableContainer"
import Paper from "@mui/material/Paper"
import Table from "@mui/material/Table"
import TableHead from "@mui/material/TableHead"
import TableRow from "@mui/material/TableRow"
import TableCell from "@mui/material/TableCell"
import TableBody from "@mui/material/TableBody"

export function TableauResultatsCandidatsLegislatives({blocs, candidats, nuances, donnees}) {
  const voixCandidats = donnees?.voix ?? {}
  const candidatsTriees = trierCandidats(candidats, voixCandidats)

  return <>
    <TableContainer component={Paper}>
      <Table sx={{ minWidth: 650 }} aria-label="simple table">
        <TableHead>
          <TableRow>
            <TableCell>Numéro</TableCell>
            <TableCell>Candidat</TableCell>
            <TableCell colSpan={2}>Nuance</TableCell>
            <TableCell colSpan={2}>Bloc</TableCell>
            <TableCell>Voix</TableCell>
            <TableCell>% Inscrit⋅es</TableCell>
            <TableCell>% Exprimé⋅es</TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {candidatsTriees.map((candidat) => (
            <LigneCandidat key={candidat.numero} candidat={candidat} voix={voixCandidats[candidat.numero] || 0}
                           donnees={donnees} nuances={nuances} blocs={blocs} />
          ))}
        </TableBody>
      </Table>
    </TableContainer>
  </>
}

function LigneCandidat({candidat, voix, donnees, nuances, blocs}) {
  const nuance = nuances.filter(nuance => nuance.code === candidat.nuance)[0]
  const bloc = blocs.filter(bloc => bloc.nom === candidat.bloc)[0]

  return <TableRow key={candidat.numero}>
    <TableCell>{candidat.numero}</TableCell>
    <TableCell>{candidat.prenom} {candidat.nom}</TableCell>
    <TableCell sx={{backgroundColor: nuance.couleur, padding: "0.2em"}}></TableCell>
    <TableCell>{nuance.nom} ({nuance.code})</TableCell>
    <TableCell sx={{backgroundColor: bloc.couleur, padding: "0.2em"}}></TableCell>
    <TableCell>{bloc.nom}</TableCell>
    <TableCell>{voix}</TableCell>
    <TableCell>{(100 * voix / donnees.inscrits).toFixed(2)} %</TableCell>
    <TableCell>{(100 * voix / donnees.exprimes).toFixed(2)} %</TableCell>
  </TableRow>
}

/**
 * Composant pour le tableau des résultats des élections législatives
 * @param blocs
 * @param nuances
 * @param donnees
 * @return {JSX.Element}
 * @constructor
 */
export function TableauResultatsNuancesLegislatives({blocs, nuances, donnees}) {
  const voixNuances = donnees?.voix ?? {}
  const nuancesTriees = trierCandidats(nuances, voixNuances, "code")

  return <>
    <TableContainer component={Paper}>
      <Table sx={{ minWidth: 650 }} aria-label="simple table">
        <TableHead>
          <TableRow>
            <TableCell colSpan={2}>Nuance</TableCell>
            <TableCell colSpan={2}>Bloc</TableCell>
            <TableCell>Voix</TableCell>
            <TableCell>% Inscrit⋅es</TableCell>
            <TableCell>% Exprimé⋅es</TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {nuancesTriees.map((nuance) => (
            <LigneNuance key={nuance.code} nuance={nuance} voix={voixNuances[nuance.code] || 0}
                         donnees={donnees} blocs={blocs} />
          ))}
        </TableBody>
      </Table>
    </TableContainer>
  </>
}

function LigneNuance({nuance, voix, donnees, blocs}) {
  const bloc = blocs.filter(bloc => bloc.nom === nuance.bloc)[0]

  return <TableRow key={nuance.code}>
    <TableCell sx={{backgroundColor: nuance.couleur, padding: "0.2em"}}></TableCell>
    <TableCell>{nuance.nom} ({nuance.code})</TableCell>
    <TableCell sx={{backgroundColor: bloc.couleur, padding: "0.2em"}}></TableCell>
    <TableCell>{bloc.nom}</TableCell>
    <TableCell>{voix}</TableCell>
    <TableCell>{(100 * voix / donnees.inscrits).toFixed(2)} %</TableCell>
    <TableCell>{(100 * voix / donnees.exprimes).toFixed(2)} %</TableCell>
  </TableRow>
}
